@@ -1,5 +1,5 @@
 package Bijection;
-use 5.006; use strict; use warnings; our $VERSION = '0.04';
+use 5.006; use strict; use warnings; our $VERSION = '1.00';
 use Import::Export; use base qw/Import::Export/;
 use Carp qw/croak/;
 our %EX = (biject => [qw/all main/], inverse => [qw/all main/], bijection_set => [qw/all set/], offset_set => [qw/all set/]);
@@ -29,9 +29,9 @@ sub biject {
 
 sub inverse {
 	my ($out, $id) = (@_, 0);
-	$id = exists $INDEX{$_} 
-		? $id * $COUNT + $INDEX{$_} 
-		: croak "invalid character $_ in $out" 
+	$id = exists $INDEX{$_}
+		? $id * $COUNT + $INDEX{$_}
+		: croak "invalid character $_ in $out"
 	for (split //, $out);
 	$id - $OFFSET;
 }
@@ -44,21 +44,14 @@ __END__
 
 Bijection - Bijection of an integer.
 
-=for html
-<a href="https://travis-ci.org/ThisUsedToBeAnEmail/Bijection"><img src="https://travis-ci.org/ThisUsedToBeAnEmail/Bijection.svg?branch=master" alt="Build Status"></a>
-<a href="https://coveralls.io/r/ThisUsedToBeAnEmail/Bijection?branch=master"><img src="https://coveralls.io/repos/ThisUsedToBeAnEmail/Bijection/badge.svg?branch=master" alt="Coverage Status"></a>
-<a href="https://metacpan.org/pod/Bijection"><img src="https://badge.fury.io/pl/Bijection.svg" alt="CPAN version"></a>
-
 =head1 VERSION
 
-Version 0.04
+Version 1.00
 
 =cut
 
 =head1 SYNOPSIS
 
-Quick summary of what the module does.
-
 Perhaps a little code snippet.
 
 	use Bijection qw/biject inverse/;
@@ -71,7 +64,7 @@ Perhaps a little code snippet.
 
 	use Bijection qw/all/;
 
-	my $offset = 100000000; 
+	my $offset = 100000000;
 	bijection_set($offset, reverse @Bijection::ALPHA[9 .. $#Bijection::ALPHA]);
 
 	my $int = 2;
@@ -83,18 +76,30 @@ Perhaps a little code snippet.
 
 =head2 biject
 
+Takes an integer and returns a bijected string.
+
 =cut
 
 =head2 inverse
 
+Takes an bijected string and returns an integer.
+
 =cut
 
 =head2 bijection_set
 
+Set the bijective pair "set", this function expects a list of alphanumeric characters.
+
+The following is set by default:
+
+	bijection_set(qw/b c d f g h j k l m n p q r s t v w x y z B C D F G H J K L M N P Q R S T V W X Y Z 0 1 2 3 4 5 6 7 8 9/);
+
 =cut
 
 =head2 offset_set
 
+Offset the bijection by setting an integer value here. This value is used to sum during bijection and substract during inversion.
+
 =cut
 
 =head1 AUTHOR
